# Learning from sequntial genomic data
# Task: load FASTA files and vectorize them with k-mers 

library(ape) # use the DNAbin format from ape to deal with fasta
library(kmer) # quickly compute k-mer frequency
library(ggplot2) # comparative barplot

# read FASTA files, store them in binary format
pos<-read.FASTA(file = "posIntron.fasta")
neg<-read.FASTA(file = "negIntron.fasta")

# see the second intron and the third random sequence
paste(unlist(as.character(pos[2])),collapse="")
paste(unlist(as.character(neg[3])),collapse="")

# find k-mer frequency, may take a couple of seconds
k<-2
kmpos<-kcount(pos,residues="DNA",k=k)
kmneg<-kcount(neg,residues="DNA",k=k)

# the output is a frequency matrix
head(kmpos)

# comparative (normalized) barplot
kmposagg<-colSums(kmpos)
kmnegagg<-colSums(kmneg)

kmnorm<-data.frame(kmer=rep(names(kmposagg),2),freq=c(kmposagg/sum(kmposagg),kmnegagg/sum(kmnegagg)),type=rep(c("intron","random"),each=length(kmposagg)))
ggplot(kmnorm, aes(factor(kmer), freq, fill = type)) + 
  geom_bar(stat="identity", position = "dodge") + 
  scale_fill_brewer(palette = "Set1")
